==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/addconstraintteachersintervalmaxdaysperweekform.h <==
/***************************************************************************
                          addconstraintteachersintervalmaxdaysperweekform.h  -  description
                             -------------------
    begin                : 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERSINTERVALMAXDAYSPERWEEKFORM_H
#define ADDCONSTRAINTTEACHERSINTERVALMAXDAYSPERWEEKFORM_H

#include "ui_addconstraintteachersintervalmaxdaysperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeachersIntervalMaxDaysPerWeekForm : public QDialog, Ui::AddConstraintTeachersIntervalMaxDaysPerWeekForm_template  {
	Q_OBJECT
public:
	AddConstraintTeachersIntervalMaxDaysPerWeekForm();
	~AddConstraintTeachersIntervalMaxDaysPerWeekForm();

	void updateMaxDaysSpinBox();
	void updateStartHoursComboBox();
	void updateEndHoursComboBox();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif

==> fet_5.38.1.orig.tar.bz2: fet-5.38.1/src/interface/addconstraintteachersintervalmaxdaysperweekform.h <==
/***************************************************************************
                          addconstraintteachersintervalmaxdaysperweekform.h  -  description
                             -------------------
    begin                : 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERSINTERVALMAXDAYSPERWEEKFORM_H
#define ADDCONSTRAINTTEACHERSINTERVALMAXDAYSPERWEEKFORM_H

#include "ui_addconstraintteachersintervalmaxdaysperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeachersIntervalMaxDaysPerWeekForm : public QDialog, Ui::AddConstraintTeachersIntervalMaxDaysPerWeekForm_template  {
	Q_OBJECT
public:
	AddConstraintTeachersIntervalMaxDaysPerWeekForm(QWidget* parent);
	~AddConstraintTeachersIntervalMaxDaysPerWeekForm();

	void updateMaxDaysSpinBox();
	void updateStartHoursComboBox();
	void updateEndHoursComboBox();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif
